@@ -8,8 +8,8 @@
 #include <vector>
 
 #include "base/memory/linked_ptr.h"
+#include "device/hid/hid_collection_info.h"
 #include "device/hid/hid_report_descriptor_item.h"
-#include "device/hid/hid_usage_and_page.h"
 
 namespace device {
 
@@ -18,16 +18,20 @@ namespace device {
 class HidReportDescriptor {
 
  public:
-  HidReportDescriptor(const uint8_t* bytes, size_t size);
+  HidReportDescriptor(const std::vector<uint8>& bytes);
   ~HidReportDescriptor();
 
   const std::vector<linked_ptr<HidReportDescriptorItem> >& items() const {
     return items_;
   }
 
-  // Returns HID usages of top-level collections present in the descriptor.
-  void GetTopLevelCollections(
-      std::vector<HidUsageAndPage>* topLevelCollections);
+  // Returns top-level collections present in the descriptor,
+  // together with max report sizes
+  void GetDetails(std::vector<HidCollectionInfo>* top_level_collections,
+                  bool* has_report_id,
+                  size_t* max_input_report_size,
+                  size_t* max_output_report_size,
+                  size_t* max_feature_report_size);
 
  private:
   std::vector<linked_ptr<HidReportDescriptorItem> > items_;
